import React, { useCallback, useEffect, useRef, useState } from 'react';
import { StyleSheet, TextInput, View } from 'react-native';
import { BoxDigit } from '../box-digit';
import { EMPTY_VALUE, initCode, isAutoFillSupported, keysValid } from '../../common/constants';
export const OTPInput = _ref => {
  let {
    onSubmit,
    autoSubmit,
    pinCount = 6,
    boxSelectedStyle,
    boxStyle,
    digitStyle,
    boxContainerStyle,
    variant = 'default'
  } = _ref;
  const [code, setCode] = useState(initCode(pinCount));
  const [idxFocusing, setIdxFocusing] = useState(0);
  const inputRef = useRef();
  const handleOnPress = idx => {
    return () => {
      var _inputRef$current, _inputRef$current$foc;
      inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : (_inputRef$current$foc = _inputRef$current.focus) === null || _inputRef$current$foc === void 0 ? void 0 : _inputRef$current$foc.call(_inputRef$current);
      setIdxFocusing(idx);
    };
  };

  // Handle box digit here
  const handleOnKeyPress = _ref2 => {
    let {
      nativeEvent: {
        key
      }
    } = _ref2;
    if (key === 'Backspace') {
      if (idxFocusing >= 0) {
        if (idxFocusing > 0 && !code[idxFocusing]) {
          setIdxFocusing(preValue => preValue - 1);
        }
        const newCode = code.map((item, idx) => idx === idxFocusing ? '' : item);
        if (!autoSubmit) {
          const otp = newCode.join('');
          onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(otp);
        }
        setCode(newCode);
      }
      return;
    }
    const keyPressed = key.trim();
    if (idxFocusing <= pinCount - 1 && keysValid(keyPressed)) {
      const keyPressedLength = keyPressed.length;
      if (keyPressedLength === 1) {
        const newCode = [...code];
        newCode[idxFocusing] = keyPressed;
        if (!autoSubmit) {
          const otp = newCode.join('');
          onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(otp);
        }
        setCode(newCode);
        if (idxFocusing < pinCount - 1) {
          setIdxFocusing(preValue => preValue + 1);
        }
      } else {
        const newCode = [];
        for (let i = 0; i < keyPressedLength; i++) {
          newCode[i] = keyPressed[i];
        }
        if (!autoSubmit) {
          const otp = newCode.join('');
          onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(otp);
        }
        setCode(newCode);
        const idxDigitFocusing = keyPressedLength < 1 ? 0 : keyPressedLength >= pinCount ? pinCount - 1 : keyPressedLength;
        setIdxFocusing(() => idxDigitFocusing);
      }
    }
  };

  // Handle submit otp here
  const handleSubmit = useCallback(() => {
    try {
      const otp = code.join('');
      if (otp.length === pinCount) {
        var _inputRef$current2, _inputRef$current2$cl;
        (_inputRef$current2 = inputRef.current) === null || _inputRef$current2 === void 0 ? void 0 : (_inputRef$current2$cl = _inputRef$current2.clear) === null || _inputRef$current2$cl === void 0 ? void 0 : _inputRef$current2$cl.call(_inputRef$current2);
        setCode(initCode(pinCount));
        setIdxFocusing(0);
        onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(otp);
      }
    } catch (error) {}
  }, [code, onSubmit, pinCount]);

  // effect
  useEffect(() => {
    if (autoSubmit) {
      handleSubmit();
    }
  }, [autoSubmit, handleSubmit]);
  useEffect(() => {
    setTimeout(() => {
      var _inputRef$current3, _inputRef$current3$fo;
      inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current3 = inputRef.current) === null || _inputRef$current3 === void 0 ? void 0 : (_inputRef$current3$fo = _inputRef$current3.focus) === null || _inputRef$current3$fo === void 0 ? void 0 : _inputRef$current3$fo.call(_inputRef$current3);
    }, 600);
  }, []);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.boxContainer, boxContainerStyle]
  }, initCode(pinCount).map((_, idx) => {
    const digit = code[idx] || EMPTY_VALUE;
    const isValueFocused = idxFocusing === idx;
    return /*#__PURE__*/React.createElement(BoxDigit, {
      key: `${idx}`,
      handleOnPress: handleOnPress(idx),
      isValueFocused,
      digit,
      pinCount,
      boxSelectedStyle,
      boxStyle,
      digitStyle,
      variant
    });
  })), /*#__PURE__*/React.createElement(TextInput, {
    style: styles.inputContainer,
    onKeyPress: handleOnKeyPress,
    maxLength: pinCount,
    ref: inputRef,
    textContentType: isAutoFillSupported ? 'oneTimeCode' : 'none',
    keyboardType: "numeric"
  }));
};
const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: 72
  },
  inputContainer: {
    width: 0,
    height: '100%',
    zIndex: -1,
    opacity: 1,
    ...StyleSheet.absoluteFillObject
  },
  boxContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingHorizontal: 20
  }
});
//# sourceMappingURL=index.js.map